@@ -14,8 +14,11 @@ use crate::sink::frame::Frame;
 use crate::sink::paintable::Paintable;
 
 use glib::thread_guard::ThreadGuard;
+use gtk::glib;
 use gtk::prelude::*;
-use gtk::{gdk, glib};
+
+#[cfg(any(target_os = "macos", target_os = "windows", feature = "gst-gl"))]
+use gtk::gdk;
 
 #[cfg(any(target_os = "macos", target_os = "windows", feature = "gst-gl"))]
 use gst_gl::prelude::GLContextExt as GstGLContextExt;
@@ -147,7 +150,7 @@ impl ObjectImpl for PaintableSink {
                 // GtkBin was dropped for GTK4 https://gitlab.gnome.org/GNOME/gtk/-/commit/3c165b3b77
                 if glib::types::Type::from_name("GtkBin").is_some() {
                     gst::error!(CAT, imp = self, "Skipping the creation of paintable to avoid segfault between GTK3 and GTK4");
-                    return None::<&gdk::Paintable>.to_value();
+                    return None::<&Paintable>.to_value();
                 }
 
                 let mut paintable_guard = self.paintable.lock().unwrap();
@@ -161,7 +164,7 @@ impl ObjectImpl for PaintableSink {
                     Some(ref paintable) => paintable,
                     None => {
                         gst::error!(CAT, imp = self, "Failed to create paintable");
-                        return None::<&gdk::Paintable>.to_value();
+                        return None::<&Paintable>.to_value();
                     }
                 };
 
@@ -172,7 +175,7 @@ impl ObjectImpl for PaintableSink {
                         imp = self,
                         "Can't retrieve Paintable from non-main thread"
                     );
-                    return None::<&gdk::Paintable>.to_value();
+                    return None::<&Paintable>.to_value();
                 }
 
                 let paintable = paintable.get_ref().clone();
@@ -784,15 +787,13 @@ impl PaintableSink {
 
             if formats.is_empty() {
                 // Filter out dmabufs caps from the template pads if we have no supported formats
-                if !matches!(&*GL_CONTEXT.lock().unwrap(), GLContext::Initialized { .. }) {
-                    tmp_caps = tmp_caps
-                        .iter_with_features()
-                        .filter(|(_, features)| {
-                            !features.contains(gst_allocators::CAPS_FEATURE_MEMORY_DMABUF)
-                        })
-                        .map(|(s, c)| (s.to_owned(), c.to_owned()))
-                        .collect::<gst::Caps>();
-                }
+                tmp_caps = tmp_caps
+                    .iter_with_features()
+                    .filter(|(_, features)| {
+                        !features.contains(gst_allocators::CAPS_FEATURE_MEMORY_DMABUF)
+                    })
+                    .map(|(s, c)| (s.to_owned(), c.to_owned()))
+                    .collect::<gst::Caps>();
             } else {
                 let tmp_caps = tmp_caps.make_mut();
                 for (s, f) in tmp_caps.iter_with_features_mut() {
@@ -973,7 +974,7 @@ impl PaintableSink {
             "GdkX11GLContextEGL" => (),
             #[cfg(feature = "x11glx")]
             "GdkX11GLContextGLX" => (),
-            #[cfg(feature = "wayland")]
+            #[cfg(feature = "waylandegl")]
             "GdkWaylandGLContext" => (),
             #[cfg(target_os = "macos")]
             "GdkMacosGLContext" => (),
@@ -1003,7 +1004,7 @@ impl PaintableSink {
             "GdkX11GLContextEGL" => self.initialize_x11egl(gdk_display),
             #[cfg(feature = "x11glx")]
             "GdkX11GLContextGLX" => self.initialize_x11glx(gdk_display),
-            #[cfg(feature = "wayland")]
+            #[cfg(feature = "waylandegl")]
             "GdkWaylandGLContext" => self.initialize_waylandegl(gdk_display),
             #[cfg(target_os = "macos")]
             "GdkMacosGLContext" => self.initialize_macosgl(gdk_display),
@@ -1149,7 +1150,7 @@ impl PaintableSink {
         }
     }
 
-    #[cfg(feature = "wayland")]
+    #[cfg(feature = "waylandegl")]
     fn initialize_waylandegl(
         &self,
         display: gdk::Display,
